@@ -4,6 +4,7 @@
 
 import json
 from functools import partial
+from typing import Dict, List
 
 
 def parse_routes(oa_file, package_name: str) -> list:
@@ -95,7 +96,7 @@ def group_params_by_query_method(params: list) -> dict:
     :return: grouped parameters
     :rtype: dict
     """
-    param_types = {}
+    param_types: Dict[str, List] = {}
     for param in params:
         add_to_type_group = partial(
             add_object_to_grouping, item=param, grouping=param_types
