@@ -3,6 +3,7 @@
 # SPDX-License-Identifier: EUPL-1.2
 
 import logging
+import pydantic
 from minty.exceptions import Conflict, Forbidden, NotFound, ValidationError
 from pyramid.view import exception_view_config
 
@@ -145,3 +146,23 @@ def exception_cqrs_catch_all(exc, request):
 
     request.response.status = 500
     return body
+
+
+@exception_view_config(pydantic.ValidationError, renderer="json")
+def exception_cqrs_validation_pydantic(exc: pydantic.ValidationError, request):
+    errors = []
+
+    for error in exc.errors():
+        errors.append(
+            {
+                "title": error.get("msg"),
+                "detail": error.get("ctx"),
+                "source": error.get("loc"),
+                "code": f"validation/{error.get('type', 'unknown')}",
+            }
+        )
+
+    body = {"errors": errors}
+    request.response.status = 400
+
+    return body
