@@ -3,6 +3,7 @@
 # SPDX-License-Identifier: EUPL-1.2
 
 import logging
+import minty
 import statsd
 from minty import Base
 from minty.config.parser.apache import ApacheConfigParser
@@ -10,7 +11,6 @@ from minty.infrastructure import _parse_global_config
 from minty.logging.mdc import get_mdc, mdc
 from minty_pyramid.renderer import jsonapi
 from pyramid.config import Configurator
-from typing import cast
 from uuid import uuid4
 
 
@@ -106,25 +106,21 @@ class RequestTimer(Base):
         self.registry = registry
 
     def __call__(self, request):
-        """Log time and count to statsd before and after execution of handler.
-
-        :param request: request
-        :type request: class
-        :return: response
-        :rtype: class
-        """
-        timer = cast(statsd.Timer, self.statsd.get_timer())
-
-        timer.start()
-
-        response = self.handler(request)
+        "Log time and count to statsd before and after execution of handler."
 
         try:
-            req_name = request.matched_route.name
-        except AttributeError:
-            req_name = "unknown"
+            # Pre-build the timer & counter objects, so it doesn't matter if
+            # `self.handler` (re)sets the context in `minty.STATSD`.
+            minty.STATSD.context = request.host.replace(".", "_")
+            timer = self.statsd.get_timer("request_duration")
+            counter = self.statsd.get_counter("number_of_requests")
 
-        timer.stop(f"request_time,route={req_name},code={response.status_int}")
+            with timer.time():
+                response = self.handler(request)
+
+            counter.increment(str(response.status_int), delta=1)
+        finally:
+            minty.STATSD.context = None
 
         return response
 
