@@ -9,6 +9,7 @@ from .exception_handlers import (
     exception_cqrs_forbidden,
     exception_cqrs_not_found,
     exception_cqrs_validation,
+    exception_cqrs_validation_pydantic,
 )
 from .generic_loader import GenericEngine, log_record_factory
 from .session_manager import SessionRetriever, session_manager_factory
@@ -112,6 +113,9 @@ class Engine(GenericEngine):
         config.add_view(view=exception_cqrs_forbidden, name="forbidden")
         config.add_view(view=exception_cqrs_conflict, name="conflict")
         config.add_view(view=exception_cqrs_validation, name="validation")
+        config.add_view(
+            view=exception_cqrs_validation_pydantic, name="validation_pydantic"
+        )
         config.add_view(view=exception_cqrs_catch_all, name="catch_all")
 
         config.add_tween("minty_pyramid.generic_loader.RequestTimer")
@@ -180,7 +184,8 @@ def _build_cqrs_setup(cqrs):
 
 
 def _build_http_session_manager(
-    session_manager: SessionRetriever, cookie_name: str = "minty_cookie",
+    session_manager: SessionRetriever,
+    cookie_name: str = "minty_cookie",
 ):
     """Create a callable to set up the `retrieve_session` method on request objects.
 
