@@ -8,7 +8,6 @@ import json
 import logging
 import minty.cqrs
 import requests.exceptions
-import statsd
 import time
 from . import oidc
 from collections import defaultdict
@@ -20,7 +19,7 @@ from pyramid.httpexceptions import (
     HTTPUnauthorized,
 )
 from redis import StrictRedis
-from typing import Dict, List, Sequence, cast
+from typing import Dict, List, Sequence
 from uuid import UUID
 
 SCOPE_PREFIX = "zs:"
@@ -71,37 +70,34 @@ class SessionRetriever(Base):
         :return: the session data
         :rtype: dict
         """
-        now = time.time()
 
-        timer = cast(statsd.Timer, self.statsd.get_timer("retrieve_session"))
-        counter = cast(statsd.Counter, self.statsd.get_counter("retrieve"))
+        timer = self.statsd.get_timer("session_database_read_duration")
 
         with timer.time():
             expiration = self.redis.get(f"expires:{session_id}")
 
             if expiration is None:
                 self.logger.info(f"Session '{session_id}' not found")
-                counter.increment("redis.session_not_found.count")
                 raise SessionNotFoundError(session_id)
 
+            now = time.time()
             if float(expiration) < now:
                 self.logger.info(f"Session '{session_id}' has expired")
-                counter.increment("redis.session_not_found.count")
                 raise SessionNotFoundError(session_id)
 
             session_data_raw = self.redis.get(f"json:session:{session_id}")
 
-            if session_data_raw is None:
-                self.logger.info(f"Session '{session_id}' not found")
-                counter.increment("redis.session_not_found.count")
-                raise SessionDataNotFoundError(session_id)
+        if session_data_raw is None:
+            self.logger.info(f"Session '{session_id}' not found")
+            raise SessionDataNotFoundError(session_id)
 
-            session_data_decoded = codecs.decode(session_data_raw, "base64")
-            session_data = json.loads(session_data_decoded)
+        session_data_decoded = codecs.decode(session_data_raw, "base64")
+        session_data = json.loads(session_data_decoded)
 
-            self.logger.debug(f"Session '{session_id}' retrieved")
+        self.logger.debug(f"Session '{session_id}' retrieved")
 
-            return session_data
+        self.statsd.get_counter("session_database_read_number").increment()
+        return session_data
 
 
 def redis_from_config(config: dict) -> StrictRedis:
@@ -130,14 +126,36 @@ def session_manager_factory(infra_factory):
     infra_factory.register_infrastructure(
         name="redis", infrastructure=redis_from_config
     )
-    redis = infra_factory.get_infrastructure(
-        context=None, infrastructure_name="redis"
-    )
+
+    timer = infra_factory.statsd.get_timer("session_database_connect_duration")
+    with timer.time():
+        redis = infra_factory.get_infrastructure(
+            context=None, infrastructure_name="redis"
+        )
+
+    infra_factory.statsd.get_counter("session_database_connect_number")
+
     return SessionRetriever(redis)
 
 
+# This class is added because when using a default dict with a lambda to
+# provide a default value if no key is present, the get method will not
+# always return the default value, but None instead. A small example below:
+#
+# permissions.get("admin")  # None
+# permissions["admin"]      # True
+# permissions.get("admin")  # True
+class default_true_dict(defaultdict):
+    def __init__(self, **kwargs):
+        super().__init__(lambda: True, **kwargs)
+
+    def get(self, __key, __default=None):
+        # ignore _default here, use the callable default form the constructor
+        return self[__key]
+
+
 def get_logged_in_user(request, logger: logging.Logger) -> minty.cqrs.UserInfo:
-    """ Get the logged in user from the given pyramid request object
+    """Get the logged in user from the given pyramid request object
 
     Args:
         request: the pyramid request object to get the user from
@@ -146,14 +164,11 @@ def get_logged_in_user(request, logger: logging.Logger) -> minty.cqrs.UserInfo:
     Returns:
         user_info: dict containing values from handle_session_data()
     """
-
     try:
         request.assert_platform_key()
 
         user_uuid = request.get_platform_user_uuid()
-        permissions: Dict[str, bool] = defaultdict(
-            lambda: True, pip_user=False
-        )
+        permissions: Dict[str, bool] = default_true_dict(pip_user=False)
 
         user_info = minty.cqrs.UserInfo(user_uuid, permissions)
         logger.info("Platform key used successfully")
@@ -238,7 +253,6 @@ def protected_route(permission="gebruiker", *args):
                         "error": "You do not have permission to access this."
                     }
                 )
-
             return view(request=request, user_info=user_info)
 
         return view_wrapper
